Package: mirTarRnaSeq
Type: Package
Title: mirTarRnaSeq
Version: 1.20.0
Authors@R: 
    c(person(given = "Mercedeh",
           family = "Movassagh",
           role = c("aut", "cre"),
           email = "mercedeh@ds.dfci.harvard.edu",
           comment = c(ORCID = "0000-0001-7690-0230")),
           person("Sarah","Morton", role="aut"),
           person("Rafael","Irizarry", role="aut"),
           person("Jeffrey", "Bailey", role= "aut"),
           person("Joseph N", "Paulson", email="paulson.joseph@gene.com", role="aut"))
Description: mirTarRnaSeq R package can be used for interactive mRNA miRNA sequencing statistical analysis. This package utilizes expression or differential expression mRNA and miRNA sequencing results and performs interactive correlation and various GLMs (Regular GLM, Multivariate GLM, and Interaction GLMs ) analysis between mRNA and miRNA expriments. These experiments can be time point experiments, and or condition expriments.
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
Depends: R (>= 4.1.0), ggplot2
DeploySubPath: mirTarRnaSeq
biocViews: miRNA, Regression, Software, Sequencing, SmallRNA,
        TimeCourse, DifferentialExpression
RoxygenNote: 7.2.3
Suggests: BiocStyle, knitr, rmarkdown, R.cache, SPONGE
VignetteBuilder: knitr
Imports: purrr, MASS, pscl, assertthat, caTools, dplyr, pheatmap,
        reshape2, corrplot, grDevices, graphics, stats, utils,
        data.table, R.utils, viridis
git_url: https://git.bioconductor.org/packages/mirTarRnaSeq
git_branch: RELEASE_3_23
git_last_commit: ff41128
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:50:51 UTC; biocbuild
Author: Mercedeh Movassagh [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7690-0230>),
  Sarah Morton [aut],
  Rafael Irizarry [aut],
  Jeffrey Bailey [aut],
  Joseph N Paulson [aut]
Maintainer: Mercedeh Movassagh <mercedeh@ds.dfci.harvard.edu>
Built: R 4.6.0; ; 2026-04-29 04:50:51 UTC; unix
