# Generated by roxygen2: do not edit by hand

export(combiner)
export(corMirnaRna)
export(corMirnaRnaMiranda)
export(drawCorPlot)
export(drawInterPlots)
export(fdrSig)
export(finInterResult)
export(geneVari)
export(getInputSpecies)
export(glm_gaussian)
export(glm_multi)
export(glm_nb)
export(glm_poisson)
export(glm_zeroinfl)
export(glm_zeroinfl_negbin)
export(glm_zeroinfl_poisson)
export(miRanComp)
export(miRandaIntersect)
export(mirRnaDensityCor)
export(mirRnaDensityInter)
export(mirRnaHeatmap)
export(mirRnaHeatmapDiff)
export(mirandaIntersectInter)
export(miranda_sponge_predict)
export(modelAIC)
export(modelCoefficients)
export(modelData)
export(modelModelName)
export(modelModelPvalue)
export(modelTermPvalues)
export(modelsFilter)
export(one2OneRnaMiRNA)
export(one2manySponge)
export(plotFit)
export(plotResiduals)
export(plotTerms)
export(runAllMirnaModels)
export(runModel)
export(runModels)
export(sampCorRnaMirna)
export(threshSig)
export(threshSigInter)
export(twoTimePoint)
export(twoTimePointSamp)
export(tzTrans)
import(R.utils)
importFrom(MASS,glm.nb)
importFrom(assertthat,assert_that)
importFrom(caTools,combs)
importFrom(corrplot,corrplot)
importFrom(data.table,fread)
importFrom(dplyr,`%>%`)
importFrom(dplyr,filter)
importFrom(dplyr,mutate)
importFrom(dplyr,select)
importFrom(grDevices,colorRampPalette)
importFrom(graphics,abline)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(pheatmap,pheatmap)
importFrom(pscl,zeroinfl)
importFrom(pscl,zeroinfl.control)
importFrom(purrr,is_formula)
importFrom(reshape2,dcast)
importFrom(stats,AIC)
importFrom(stats,cor)
importFrom(stats,density)
importFrom(stats,deviance)
importFrom(stats,df.residual)
importFrom(stats,formula)
importFrom(stats,gaussian)
importFrom(stats,glm)
importFrom(stats,glm.control)
importFrom(stats,lm)
importFrom(stats,model.frame)
importFrom(stats,p.adjust)
importFrom(stats,pchisq)
importFrom(stats,pf)
importFrom(stats,poisson)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,terms)
importFrom(stats,var)
importFrom(utils,download.file)
importFrom(utils,read.table)
importFrom(viridis,inferno)
