<img src="man/figures/logo.png" align="right" alt="logo.png" width="180" />

# mirTarRnaSeq

<!-- badges: start -->
[![BioC status](http://www.bioconductor.org/shields/build/release/bioc/mirTarRnaSeq.svg)](https://bioconductor.org/checkResults/release/bioc-LATEST/mirTarRnaSeq)
<!-- badges: end -->

## Installation
```
devtools::install_github('Mercedeh66/mirTarRnaSeq')
```
## Issues and bug reports
Please use https://github.com/Mercedeh66/mirTarRnaSeq/issues to submit issues, bug reports, and comments.
