#' This is data is the mRNA expression across samples and miRNA expression data which is to be
#' investigated in one file. This data set is used in documentation examples.
#'
#' @name Combine
#' @docType data
#' @keywords data
NULL

#' This is data is the mRNA FC and miRNA FC correlation data.
#' This data set is used in documentation examples.
#'
#' @name corr_0
#' @docType data
#' @keywords data
NULL

#' This is data is the mRNA FC and miRNA FC correlation/interaction data results after filteration.
#' This data set is used in documentation examples.
#'
#' @name final_results
#' @docType data
#' @keywords data
NULL

#' This is data is the mRNA expression across samples and miRNA expression data which is to be
#' investigated giving directions on which data is miRNA and which is mRNA.
#' This data set is used in documentation examples.
#'
#' @name geneVariant
#' @docType data
#' @keywords data
NULL

#' This is data is the mRNA FC and miRNA FC correlation/interaction original data.
#' This data set is used in documentation examples.
#'
#' @name inter0
#' @docType data
#' @keywords data
NULL

#' This is data is the mRNA expression file.
#' This data set is used in documentation examples.
#'
#' @name mRNA
#' @docType data
#' @keywords data
NULL

#' This is data is the miRNA expression file.
#' This data set is used in documentation examples.
#'
#' @name miRNA
#' @docType data
#' @keywords data
NULL

#' This is data is the mRNA0_2 FC for 0-2 time point.
#' This data set is used in documentation examples.
#'
#' @name mRNA0_2
#' @docType data
#' @keywords data
NULL

#' This is data is the mRNA2_5 FC for 2-5 time point.
#' This data set is used in documentation examples.
#'
#' @name mRNA2_5
#' @docType data
#' @keywords data
NULL

#' This is data is the mRNA0_5 FC for 0-5 time point.
#' This data set is used in documentation examples.
#'
#' @name mRNA0_5
#' @docType data
#' @keywords data
NULL

#' This is data is the combined mRNA FC for all time points.
#' This data set is used in documentation examples.
#'
#' @name mRNA_fc
#' @docType data
#' @keywords data
NULL

#' This is data is the combined miRNA FC for all time points.
#' This data set is used in documentation examples.
#'
#' @name miRNA_fc
#' @docType data
#' @keywords data
NULL

#' This is data is the miRNA0_2 FC for 0-2 time point.
#' This data set is used in documentation examples.
#'
#' @name miRNA0_2
#' @docType data
#' @keywords data
NULL

#' This is data is the miRNA2_5 FC for 2-5 time point.
#' This data set is used in documentation examples.
#'
#' @name miRNA2_5
#' @docType data
#' @keywords data
NULL

#' This is data is the miRNA0_5 FC for 0-5 time point.
#' This data set is used in documentation examples.
#'
#' @name miRNA0_5
#' @docType data
#' @keywords data
NULL

#' This is data is the output file resulted from time point/conditions background correlation model.
#' This data set is used in documentation examples.
#'
#' @name outs
#' @docType data
#' @keywords data
NULL

#' This is data is the output file resulted from time point/conditions background difference/interelation model.
#' This data set is used in documentation examples.
#'
#' @name outs2
#' @docType data
#' @keywords data
NULL

#' This is data is the output file resulted from time point or conditions or correlation or interrelation model.
#' This data set is used in documentation examples.
#'
#' @name results
#' @docType data
#' @keywords data
NULL

#' This is data is the output file resulted from time point or conditions experiment for interrelation model after filtering and threshold modification.
#' This data set is used in documentation examples.
#'
#' @name sig_InterR
#' @docType data
#' @keywords data
NULL

#' This is data is the output file resulted from time point or conditions experiment for correlation model after filtering and threshold modification.
#' This data set is used in documentation examples.
#'
#' @name sig_corrs
#' @docType data
#' @keywords data
NULL

#' This is data is the results file from regression analysis and its estimates.
#' This data set is used in documentation examples.
#'
#' @name some_model
#' @docType data
#' @keywords data
NULL

#' This is data is the results file from mouse miRanda getInputSpecies function.
#' This data set is used in documentation examples.
#'
#' @name miRandaM
#' @docType data
#' @keywords data
NULL

#' This is data is the results file from EBV miRanda getInputSpecies function.
#' This data set is used in documentation examples.
#'
#' @name miRanda
#' @docType data
#' @keywords data
NULL

#' This data is the mRNA fold change data set for difference or interrelation section.
#' This data set is used in documentation examples.
#'
#' @name mRNA_fc2
#' @docType data
#' @keywords data
NULL

#' This data is the miRNA fold change data set for difference or interrelation section.
#' This data set is used in documentation examples.
#'
#' @name miRNA_fc2
#' @docType data
#' @keywords data
NULL
