% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{inter0}
\alias{inter0}
\title{This is data is the mRNA FC and miRNA FC correlation/interaction original data.
This data set is used in documentation examples.}
\description{
This is data is the mRNA FC and miRNA FC correlation/interaction original data.
This data set is used in documentation examples.
}
\keyword{data}
