% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/models_run.R
\name{modelAIC}
\alias{modelAIC}
\title{Obtain model AIC}
\usage{
modelAIC(x)
}
\arguments{
\item{x}{fitted model}
}
\value{
AIC for model
}
\description{
Obtain model AIC
}
\examples{
modelAIC(some_model)
}
